jQuery.Flexdatalist
======

Flexdatalist is (another) jQuery autocomplete plugin with support for <code>&lt;datalist&gt;</code>. Check the documentation page to see the plugin in action.

## Demo & Documentation ##

Check out the [examples and documentation](http://projects.sergiodinislopes.pt/flexdatalist/) page.

## Roadmap

- Improve accessibility
- Allow the search to be disabled on flexdatalist and just use the given list (from server-side)
- Use CSS grid to list multiple selected values
- Regex in JS has bad support for special and accented characters, I'll try to make some improvements __(it works since v2.3.0, but it won't highlight the word, though)__
- Make it jQuery independent (this will take a while to make it to a release)

### License
Flexdatalist is licensed under the [MIT license](http://opensource.org/licenses/MIT).
Copyright (c) 2016 - 2021 [Sérgio Dinis Lopes](http://github.com/sergiodlopes)